AppProvider class

Inheritance

Constructors

AppProvider()
factory

Properties

appodealKey String
no setter
authSub StreamSubscription<AuthState>?
getter/setter pair
currentThemeMode ThemeMode
getter/setter pair
facebookAppId String
no setter
facebookBannerAdsId String
no setter
facebookPageAdsId String
no setter
facebookRewordId String
no setter
googleAppId String
no setter
googleBannerKey String
no setter
googlePageKey String
no setter
googleRewardKey String
no setter
googleServerId String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
intlPath String
no setter
isLogin bool
no setter
isVip bool
no setter
locales Map<String, Locale>
getter/setter pair
mobile bool
no setter
money int
no setter
removeAds bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize BoxConstraints
getter/setter pair
size Size?
getter/setter pair
supabase ↔ SupabaseClient
getter/setter pair
themes Map<String, ThemeMode>
final
unityAndroidKey String
no setter
unityIosKey String
no setter
user ↔ User?
getter/setter pair
userId String
no setter
userVipDate int
no setter
userVipDateString String
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeLocale(BuildContext context, String? locale) → void
changeTheme(ThemeMode mode) → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
init({AppConfig? config}) Future
languageName(Locale lang) String?
loginAction(BuildContext context, {dynamic action()?, String? googleUrl, bool page = false}) → dynamic
logout() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
updateSize(Size? screen) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appThemeMode String
getter/setter pair
appUserAdsKey String
getter/setter pair
fullLocale Map<String, Locale>
getter/setter pair
userAppMoneyKey String
getter/setter pair
userVipDateKey String
getter/setter pair