AdsConfig class

Constructors

AdsConfig({String? googleRewardKey, String? googleBannerKey, String? googlePageKey, String? googleAppId, String? appodealKey, String? unityAndroidKey, String? unityIosKey, String? facebookAppId, String? facebookBannerAdsId, String? facebookPageAdsId, String? facebookRewordId})

Properties

appodealKey String?
getter/setter pair
facebookAppId String?
getter/setter pair
facebookBannerAdsId String?
getter/setter pair
facebookPageAdsId String?
getter/setter pair
facebookRewordId String?
getter/setter pair
googleAppId String?
getter/setter pair
googleBannerKey String?
getter/setter pair
googlePageKey String?
getter/setter pair
googleRewardKey String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unityAndroidKey String?
getter/setter pair
unityIosKey String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited