AppConfig class

Constructors

AppConfig({String? sentryUrl, String? supaUrl, String? supaAnonKey, String? googleServerId, AdsConfig? adsConfig, String? localePath, dynamic accountChange(AuthState)?})

Properties

accountChange ↔ dynamic Function(AuthState)?
getter/setter pair
adsConfig AdsConfig?
getter/setter pair
googleServerId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
localePath String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentryUrl String?
getter/setter pair
supaAnonKey String?
getter/setter pair
supaUrl String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited