ProductsData class

Constructors

ProductsData({int? id, String? productId, double? price, String? name, String? description, int? money, int? status, int? type})
ProductsData.fromJson(Map<String, dynamic> json)

Properties

description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
money int?
getter/setter pair
name String?
getter/setter pair
price double?
getter/setter pair
productId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
getter/setter pair
type int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited