SelectItem<T> class

Constructors

SelectItem({String? select, dynamic tap(T value)?, Widget? child})

Properties

child Widget?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
select String?
getter/setter pair
tap ↔ dynamic Function(T value)?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited