AppUtils class
Constructors
- AppUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
copy(
String text) → dynamic -
formatChatTimestamp(
int timestampMillis) → String -
getDeviceId(
) → Future< String?> -
getDeviceInfo(
) → Future< Map?> -
getDeviceName(
) → Future< String?> -
getDeviceType(
) → DeviceType -
launch(
String url) → Future -
millStr(
int timestampMillis) → String -
timestampToDateTime(
int timestamp) → DateTime -
timestampToString(
int timestamp) → String